@@ -1,9 +1,7 @@
 use std::fmt::Debug;
 
-use eyre::bail;
-
 use crate::backend::{Backend, BackendType};
-use crate::cache::CacheManager;
+use crate::cache::{CacheManager, CacheManagerBuilder};
 use crate::cli::args::BackendArg;
 use crate::cmd::CmdLineRunner;
 use crate::config::Settings;
@@ -65,9 +63,12 @@ impl Backend for GoBackend {
         let settings = Settings::get();
         settings.ensure_experimental("go backend")?;
 
-        if ctx.tv.version.starts_with("v") {
-            bail!("versions should not start with a 'v', please remove it");
-        }
+        let version = if ctx.tv.version.starts_with("v") {
+            warn!("usage of a 'v' prefix in the version is discouraged");
+            ctx.tv.version.to_string().replacen("v", "", 1)
+        } else {
+            ctx.tv.version.to_string()
+        };
 
         let install = |v| {
             CmdLineRunner::new("go")
@@ -79,9 +80,9 @@ impl Backend for GoBackend {
                 .execute()
         };
 
-        if install(format!("v{}", &ctx.tv.version)).is_err() {
+        if install(format!("v{}", version)).is_err() {
             warn!("Failed to install, trying again without added 'v' prefix");
-            install(ctx.tv.version.to_string())?;
+            install(version)?;
         }
 
         Ok(())
@@ -91,10 +92,11 @@ impl Backend for GoBackend {
 impl GoBackend {
     pub fn from_arg(ba: BackendArg) -> Self {
         Self {
-            remote_version_cache: CacheManager::new(
-                ba.cache_path.join("remote_versions-$KEY.msgpack.z"),
+            remote_version_cache: CacheManagerBuilder::new(
+                ba.cache_path.join("remote_versions.msgpack.z"),
             )
-            .with_fresh_duration(*env::MISE_FETCH_REMOTE_VERSIONS_CACHE),
+            .with_fresh_duration(*env::MISE_FETCH_REMOTE_VERSIONS_CACHE)
+            .build(),
             ba,
         }
     }
