@@ -26,7 +26,6 @@ use crate::toolset::{ToolRequest, ToolRequestSet, ToolSource, ToolVersionOptions
 use crate::{dirs, file};
 
 #[derive(Default, Deserialize)]
-#[serde(deny_unknown_fields)]
 pub struct MiseToml {
     #[serde(default, deserialize_with = "deserialize_version")]
     min_version: Option<Versioning>,
@@ -85,7 +84,10 @@ impl MiseToml {
     pub fn from_file(path: &Path) -> eyre::Result<Self> {
         trace!("parsing: {}", display_path(path));
         let body = file::read_to_string(path)?;
-        let mut rf: MiseToml = toml::from_str(&body)?;
+        let des = toml::Deserializer::new(&body);
+        let mut rf: MiseToml = serde_ignored::deserialize(des, |p| {
+            warn!("unknown field in {}: {p}", display_path(path));
+        })?;
         rf.context = BASE_CONTEXT.clone();
         rf.context
             .insert("config_root", path.parent().unwrap().to_str().unwrap());
@@ -286,14 +288,17 @@ impl ConfigFile for MiseToml {
             .as_table_mut()
             .unwrap();
 
+        // if a short name is used like "node", make sure we remove any long names like "core:node"
+        tools.remove(&fa.full.to_string());
+
         if versions.len() == 1 {
-            tools.insert(&fa.to_string(), value(versions[0].clone()));
+            tools.insert(&fa.short, value(versions[0].clone()));
         } else {
             let mut arr = Array::new();
             for v in versions {
                 arr.push(v);
             }
-            tools.insert(&fa.to_string(), Item::Value(Value::Array(arr)));
+            tools.insert(&fa.short, Item::Value(Value::Array(arr)));
         }
 
         Ok(())
@@ -1156,15 +1161,6 @@ mod tests {
         assert_debug_snapshot!(cf);
     }
 
-    #[test]
-    fn test_fail_with_unknown_key() {
-        reset();
-        let _ = toml::from_str::<MiseToml>(&formatdoc! {r#"
-        invalid_key = true
-        "#})
-        .unwrap_err();
-    }
-
     #[test]
     fn test_env_entries() {
         reset();
